package net.buildbox.sample.LikeSiri;

import java.util.ArrayList;

import android.net.Uri;
import android.os.Bundle;
import android.app.Activity;
import android.content.ActivityNotFoundException;
import android.content.Intent;
import android.content.res.Resources;
import android.speech.RecognizerIntent;
import android.view.Menu;
import android.view.View;
import android.widget.Toast;

public class MainActivity extends Activity {
	private static final int REQCODE_START = 100;	// 初期キー
	private static final int REQCODE_TEL   = 200;	// 電話
	private static final int REQCODE_MAP   = 300;	// 地図

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}
	
	// 音声入力画面を呼び出すIntentの発行
	public void sendSpeechIntent(int reqCode, String prompt) {
        try {
            // インテント作成
            Intent intent = new Intent(RecognizerIntent.ACTION_RECOGNIZE_SPEECH);
            intent.putExtra(
                    RecognizerIntent.EXTRA_LANGUAGE_MODEL,
                    RecognizerIntent.LANGUAGE_MODEL_FREE_FORM);
            intent.putExtra(
                    RecognizerIntent.EXTRA_PROMPT,
                    prompt);	// 音声入力時に表示するテキスト
            
            // インテント発行
            startActivityForResult(intent, reqCode);
        } catch (ActivityNotFoundException e) {
            // このインテントに応答できるアクティビティがインストールされていない場合
            Toast.makeText(this,
                "ActivityNotFoundException", Toast.LENGTH_SHORT).show();
        }
	}

	// ボタンが押された時に呼び出される
	public void onClickEvent(View v) {
		String msg_start = getResources().getString(R.string.msg_start);
		sendSpeechIntent(REQCODE_START, msg_start);
	}
	
    // アクティビティ終了時に呼び出される
    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
    	Intent requestIntent = null;
    	ArrayList<String> result = null;
    	Resources res = getResources();		// 文字列リソース取得用
    	
    	if (data == null) {
    		// 結果が取得できなかった
    		Toast.makeText(this, R.string.msg_unknown, Toast.LENGTH_SHORT).show();
    		return;
    	} else if (data != null) {
        	// 結果を文字列リストで取得
    		result = data.getStringArrayListExtra(
    				RecognizerIntent.EXTRA_RESULTS);
    	}
    	
    	// 要件の音声認識結果処理
        if (requestCode == REQCODE_START && resultCode == RESULT_OK) {
        	// キーワードが含まれているかどうかを判定し、処理を分岐
        	String keyTel = getResources().getString(R.string.key_tel);	// キーワード（電話）
        	String keyMap = getResources().getString(R.string.key_map);	// キーワード（地図）
        	if (result.get(0).indexOf(keyTel) != -1) {
        		// 電話
        		String msgTel = res.getString(R.string.msg_tel);
        		sendSpeechIntent(REQCODE_TEL, msgTel);
        	} else if (result.get(0).indexOf(keyMap) != -1) {
        		// 地図
        		String msgMap = res.getString(R.string.msg_map);
        		sendSpeechIntent(REQCODE_MAP, msgMap);
        	} else {
        		// 不明
        		Toast.makeText(this, R.string.msg_unknown, Toast.LENGTH_SHORT).show();
        	}
        // 電話番号の音声認識結果処理
        } else if (requestCode == REQCODE_TEL && resultCode == RESULT_OK) {
        	requestIntent = new Intent(Intent.ACTION_VIEW, Uri.parse("tel:" + result.get(0)));
        	startActivity(requestIntent);
        // 地図検索の音声認識結果処理
        } else if (requestCode == REQCODE_MAP && resultCode == RESULT_OK) {
        	requestIntent = new Intent(Intent.ACTION_VIEW, Uri.parse("geo:0,0?q=" + result.get(0)));
        	startActivity(requestIntent);
        }
        
        super.onActivityResult(requestCode, resultCode, data);
    }
}
